@@ -7,4 +7,5 @@ This module is used for importing all the modules of Python Commons.
 
 import __init__
 for pkg in __init__.__all__:
-    exec 'from ' + pkg + ' import *'
+    if pkg != 'async': exec 'from ' + pkg + ' import *'
+
