@@ -13,6 +13,21 @@ from L{invalid_filename_chars}.
 
 from __future__ import with_statement
 
+__all__ = '''
+soft_makedirs
+temp_dir
+cleanse_filename
+invalid_filename_chars
+invalid_filename_chars_regex
+disk_double_buffer
+versioned_guard
+versioned_cache
+read_file
+write_file
+write_or_rm
+is_nonempty_file
+'''.split()
+
 import os, re, tempfile
 from cPickle import *
 from path import path
@@ -52,7 +67,7 @@ def temp_dir( base_dir_name, do_create_subdir = True ):
     @param do_create_subdir: If C{True}, then creates a
     sub-sub-directory within the temporary sub-directory (and returns
     the path to that). The sub-sub-directory's name is randomized
-    (uses L{tempfile.mkdtemp}).
+    (uses C{tempfile.mkdtemp}).
     @type do_create_subdir: bool
 
     @return: The path to the temporary (sub-)sub-directory.
@@ -169,3 +184,22 @@ def versioned_cache(version_path, fresh_version, cache_path, cache_func):
     else:
         # cache up-to-date (should be available since dlcs-timestamp exists!)
         with file(cache_path) as f: return load(f)
+
+def read_file(path):
+    f = file(path)
+    try: return f.read()
+    finally: f.close()
+
+def write_file(path, contents):
+    f = file(path,'w')
+    try: f.write(contents)
+    finally: f.close()
+
+def write_or_rm(p, contents):
+    'Write the file or remove it if contents is empty.'
+    p = path(p)
+    if contents.strip(): write_file(p, contents)
+    elif p.isfile(): p.remove()
+
+def is_nonempty_file(path):
+    return path.isfile() and read_file(path).strip() != ''
