@@ -12,10 +12,23 @@ from itertools import chain, imap
 import logging, logging.handlers, sys
 from logging import getLogger
 
+__all__ = """
+fmt
+log
+exception
+critical
+error
+warning
+info
+die
+tailor_logs
+config_logging
+""".split()
+
 # TODO cleanup / reorganize this section
 
 def fmt( flag, *args ):
-    return ' '.join( chain( [ '%-20s:' % flag ], imap( str, args ) ) )
+    return ' '.join( chain( [ '%-20s:' % flag ], imap( unicode, args ) ) )
 
 def log( level, flag, *args ):
     getLogger( flag ).log( level, fmt( flag, *args ) )
@@ -44,7 +57,7 @@ def die( flag, *args ):
 
 def tailor_logs( flag, *prefix ):
     """
-    Avoid repetitive typing! Usage:
+    Avoid repetitive typing! Usage::
 
       debug,info,warning,_,_ = tailor_logs('myflag','some','prefix')
     """
@@ -81,7 +94,7 @@ def config_logging( level = logging.INFO,
     @type do_server: bool
 
     @param flags: The set of flags on which to lower the threshold to
-    L{logging.DEBUG}.
+    C{logging.DEBUG}.
     @type flags: iterable
 
     @param path: The path of the log file (only considered if
