@@ -48,7 +48,7 @@ if not hasattr(sys, "version_info") or sys.version_info < (2, 3):
 else:
     from setuptools import setup, find_packages
 
-def run_setup( pkg_info_text, *orig_args, **orig_kwargs ):
+def run_setup( pkg_info_text, srcdir = 'src', *orig_args, **orig_kwargs ):
     list_keys = set( [ 'Classifier' ] )
     pkg_info = {}
     for line in pkg_info_text.split( '\n' ):
@@ -92,8 +92,8 @@ def run_setup( pkg_info_text, *orig_args, **orig_kwargs ):
     # this also allows user to override our args
     args.update( orig_kwargs )
     args.update( {
-        'package_dir': {'':'src'},
-        'packages': find_packages('src'),
+        'package_dir': {'':srcdir},
+        'packages': find_packages(srcdir),
         'zip_safe': True,
     } )
 
