@@ -9,9 +9,10 @@ from __future__ import absolute_import
 from .log import ( critical, debug, config_logging )
 from .environ import ( get_environs )
 from .interp import interp
+from os.path import basename
 from sys import _current_frames
 from threading import currentThread
-import os, sys
+import os, sys, unittest
 
 class UnsetError( Exception ): pass
 
@@ -113,14 +114,17 @@ def dump_stack(*args):
     sys.stderr.flush()
     critical( '', output )
 
+def command_name():
+    return basename(sys.argv[0])
+
 def run_main( main = None, do_force = False, runner = None,
-              use_sigquit_handler = False ):
+              use_sigquit_handler = False, handle_exceptions = False ):
     """
     A feature-ful program starter. Configures logging and psyco, then
     runs the C{main} function defined in the caller's module, passing
-    in L{sys.argv}.  If the C{PYDBG} environment variable is set, then
-    runs C{main} in L{pdb}.  If the C{PYPROF} environment variable is
-    set, then runs C{main} in L{profile}.  Finally, exits with
+    in C{sys.argv}.  If the C{PYDBG} environment variable is set, then
+    runs C{main} in C{pdb}.  If the C{PYPROF} environment variable is
+    set, then runs C{main} in C{cProfile}.  Finally, exits with
     C{main}'s return value.
 
     For example::
@@ -142,6 +146,8 @@ def run_main( main = None, do_force = False, runner = None,
     except KeyError:
         pass
     else:
+        if os.environ.get( 'PYTEST', '' ) != '':
+            unittest.main()
         if do_force or runner is not None or name == '__main__':
             runner = ( ( lambda main, args: main( args ) )
                        if runner is None else runner )
@@ -149,25 +155,32 @@ def run_main( main = None, do_force = False, runner = None,
             do_debug = os.environ.get( 'PYDBG', '' ) != ''
             do_profile = os.environ.get( 'PYPROF', '' ) != ''
 
-            if do_debug:
-                import pdb
-                signal(SIGINT, lambda *args: pdb.set_trace())
-                status = pdb.runcall( runner, main, sys.argv )
-            elif do_profile:
-                from cProfile import runctx
-                container = []
-                try:
-                    outpath = os.environ[ 'PYPROF' ] % \
-                              currentThread().getName()
-                except:
-                    error( 'bad PYPROF:', os.environ[ 'PYPROF' ] )
-                    status = runner( main, sys.argv )
+            try:
+                if do_debug:
+                    import pdb
+                    signal(SIGINT, lambda *args: pdb.set_trace())
+                    status = pdb.runcall( runner, main, sys.argv )
+                elif do_profile:
+                    from cProfile import runctx
+                    container = []
+                    try:
+                        outpath = os.environ[ 'PYPROF' ] % \
+                                  currentThread().getName()
+                    except:
+                        error( 'bad PYPROF:', os.environ[ 'PYPROF' ] )
+                        status = runner( main, sys.argv )
+                    else:
+                        runctx( 'container[0] = runner( main, sys.argv )',
+                                globals(), locals(), filename = outpath )
+                        status = container[0]
                 else:
-                    runctx( 'container[0] = runner( main, sys.argv )',
-                            globals(), locals(), filename = outpath )
-                    status = container[0]
-            else:
-                status = runner( main, sys.argv )
+                    status = runner( main, sys.argv )
+            except ( KeyboardInterrupt, Exception ), ex:
+                if handle_exceptions and not isinstance( ex, AssertionError ):
+                    print >> sys.stderr, ex
+                    sys.exit(1)
+                else:
+                    raise
 
             ## watchdog timer commits suicide if after 3 seconds we
             ## still have not exited
