@@ -5,7 +5,7 @@
 Data structures: Heaps, lists, queues, and Python hacks.
 """
 
-import copy, heapq, itertools, sys
+import copy, heapq, itertools, sys, unittest
 
 class bidict( object ):
   """Bi-directional dictionary; assumes 1:1 mappings."""
@@ -19,8 +19,8 @@ class bidict( object ):
   def contains_b( self, b ): return b in self.b2a
   def __len__( self ): return len( self.a2b )
   def items( self ): return self.a2b.iteritems()
-  def as( self ): return self.a2b.keys()
-  def bs( self ): return self.b2a.keys()
+  def a_values( self ): return self.a2b.keys()
+  def b_values( self ): return self.b2a.keys()
   def clear( self ): self.a2b.clear(); self.b2a.clear()
   def remove_a( self, a ):
     b = self.a2b.pop(a)
@@ -40,12 +40,20 @@ class idict( dict ):
   def __delitem__( self, k ):
     return dict.__delitem__( self, k.lower() )
 
-class FreeStruct( object ):
+class free_struct( object ):
     """
     General-purpose namespace structure.
     """
-    def __init__( self, **args ):
+    def __init__( self, d = {}, **args ):
+        self.__dict__.update( d )
         self.__dict__.update( args )
+    def __repr__( self ):
+        fields = ( '%s = %r' % ( name, value )
+                   for name, value in self.__dict__.iteritems() )
+        return "%s(%s)" % ( self.__class__.__name__, ', '.join( fields ) )
+    def __eq__( self, other ):
+        return type( self ) == type( other ) and \
+               self.__dict__ == other.__dict__
 
 class LazyObject( object ):
     """
@@ -518,3 +526,56 @@ class Heap(ListMixin):
         if self._key is not None:
             item = item[1]
         return item
+
+def dicts2structs(x):
+    """
+    Given a tree of lists/dicts, perform a deep traversal to transform all the
+    dicts to structs.
+    """
+    if type(x) == dict:
+        return free_struct( ( k, dicts2structs(v) ) for k,v in x.iteritems())
+    elif type(x) == list:
+        return [dicts2structs(v) for v in x]
+    else:
+        return x
+
+def structs2dicts(x):
+    """
+    Given a tree of lists/structs, perform a deep traversal to transform all
+    the structs to dicts.
+    """
+    if type(x) == free_struct:
+        return dict( ( k, structs2dicts(v) ) for k,v in x.__dict__.iteritems() )
+    elif type(x) == list:
+        return [structs2dicts(v) for v in x]
+    else:
+        return x
+
+#
+# Tests.
+#
+
+class common_tests(unittest.TestCase):
+    def test_dicts_structs(self):
+        dicts = {
+                'atom': 0,
+                'dict': { 'atom': 'atom', 'list': [1,2,3] },
+                'list': [ 'atom', {'key': 'value'} ]
+                }
+
+        structs = dicts2structs(dicts)
+        self.assertEqual(structs.atom,        dicts['atom'])
+        self.assertEqual(structs.dict.atom,   dicts['dict']['atom'])
+        self.assertEqual(structs.dict.list,   dicts['dict']['list'])
+        self.assertEqual(structs.list[0],     dicts['list'][0])
+        self.assertEqual(structs.list[1].key, dicts['list'][1]['key'])
+
+        dicts2 = structs2dicts(dicts)
+        self.assertEqual(dicts2['atom'],           structs.atom)
+        self.assertEqual(dicts2['dict']['atom'],   structs.dict.atom)
+        self.assertEqual(dicts2['dict']['list'],   structs.dict.list)
+        self.assertEqual(dicts2['list'][0],        structs.list[0])
+        self.assertEqual(dicts2['list'][1]['key'], structs.list[1].key)
+
+if __name__ == '__main__':
+    unittest.main()
